#line 2 "colorbar/lex.C"

#line 4 "colorbar/lex.C"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

    /* The c++ scanner is a mess. The FlexLexer.h header file relies on the
     * following macro. This is required in order to pass the c++-multiple-scanners
     * test in the regression suite. We get reports that it breaks inheritance.
     * We will address this in a future release of flex, or omit the C++ scanner
     * altogether.
     */
    #define yyFlexLexer cbFlexLexer

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
typedef uint64_t flex_uint64_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */
#include <iostream> 
#include <errno.h>
#include <cstdlib>
#include <cstring>
/* end standard C++ headers. */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t yyleng;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{

	std::istream* yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

void *cballoc (yy_size_t  );
void *cbrealloc (void *,yy_size_t  );
void cbfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

#define yytext_ptr yytext

#include <FlexLexer.h>

int yyFlexLexer::yywrap() { return 1; }

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (yy_size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 64
#define YY_END_OF_BUFFER 65
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[244] =
    {   0,
        0,    0,   65,   63,   62,   64,   63,   63,   63,   63,
       63,   54,   54,   63,   63,   63,   63,   63,   63,   63,
       63,   63,   63,   63,   31,   63,   63,   63,   63,   63,
       63,   63,   63,   52,   63,   62,   61,    0,   61,   58,
        0,   61,   59,   61,   54,   56,   55,   61,   61,   61,
       61,   61,    4,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   61,   61,   22,   61,   61,   61,
       61,   61,   61,   61,   61,   33,   61,   35,   61,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,    0,   61,   60,   58,   59,   61,   61,   55,   57,

       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   15,   61,   61,   16,   61,   61,   61,   61,   24,
       61,   61,   61,   61,   29,   61,   61,   34,   61,   61,
       61,   61,   41,   61,   61,   44,   61,   61,   47,   61,
       61,   61,   53,   60,   61,   56,   61,   61,    3,   61,
        6,   61,   61,   61,   61,   61,   14,   61,   19,   17,
       61,   21,   61,   61,   26,   27,   61,   61,   32,   61,
       61,   61,   61,   61,   42,   43,   45,   61,   61,   61,
       61,   61,   61,    2,   61,   61,   61,   61,   12,   61,
       18,   61,   61,   25,   61,   61,   61,   37,   38,   39,

       61,   46,   61,   49,   50,   61,    1,   61,   61,   61,
       61,   61,   11,   13,   20,   23,   28,   30,   61,   61,
       61,   51,    5,   61,   61,   61,   61,   61,   61,   48,
        8,    7,   61,   10,   61,   61,   61,   61,   61,    9,
       36,   40,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    4,    5,    4,    4,    4,    4,    6,    4,
        4,    4,    7,    4,    7,    8,    4,    9,   10,   11,
       12,   10,   10,   10,   10,   10,   10,    4,    4,    4,
        4,    4,    4,    4,   13,   14,   15,   16,   17,   18,
       19,   20,   21,   22,   23,   24,   25,   26,   27,   28,
       29,   30,   31,   32,   33,   34,   35,   36,   37,    4,
        4,    4,    4,    4,    4,    4,   38,   39,   40,   41,

       42,   43,   44,   45,   46,   47,   48,   49,   50,   51,
       52,   53,   54,   55,   56,   57,   58,   59,   60,   61,
       62,    4,   63,    4,   64,    4,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[65] =
    {   0,
        1,    1,    2,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3
    } ;

static yyconst flex_int16_t yy_base[251] =
    {   0,
        0,    0,  120,  587,  107,  587,    0,   64,   66,   65,
       69,   74,   84,   71,   82,   80,   72,   82,   98,   85,
      101,  105,  124,  121,  126,  131,  125,   71,  141,  141,
      137,  152,  142,  151,  170,  104,    0,   92,  194,    0,
       84,  196,    0,  194,  199,  203,  212,  221,  246,  178,
      182,  204,    0,  205,  182,  222,  197,  226,  226,  233,
      227,  229,  234,  254,  247,  253,    0,  236,  245,  245,
      249,  268,  268,  250,  265,    0,  279,    0,  267,  278,
      283,  270,  289,  275,  283,  292,  279,  289,  284,  301,
      285,   24,  328,    0,  587,  587,  336,  226,  344,    0,

      299,  312,  309,  323,  327,  324,  327,  329,  328,  345,
      331,    0,  333,  349,    0,  331,  350,  353,  354,    0,
      355,  341,  361,  351,    0,  358,  363,    0,  349,  356,
      353,  373,    0,  382,  366,    0,  392,  377,    0,  380,
      380,  401,    0,  587,  409,  418,  383,  390,    0,  396,
        0,  393,  401,  405,  414,  406,    0,  423,    0,    0,
      423,    0,  414,  421,    0,    0,  415,  422,    0,  419,
      419,  415,  421,  430,    0,    0,    0,  438,  438,  440,
       60,  434,  430,    0,  447,  467,  453,  442,    0,  465,
        0,  451,  456,    0,  454,  467,  479,    0,    0,    0,

      462,    0,  469,    0,    0,  464,    0,  476,  488,  489,
      475,  473,    0,    0,    0,    0,    0,    0,  475,  477,
      484,    0,    0,  481,  484,  501,  484,  501,  510,    0,
        0,    0,  517,    0,  505,  511,  523,  510,  517,    0,
        0,    0,  587,   67,  568,  571,  574,  577,  580,  583
    } ;

static yyconst flex_int16_t yy_def[251] =
    {   0,
      243,    1,  243,  243,  243,  243,  244,  245,  246,  244,
      244,  244,  244,  244,  244,  244,  244,  244,  244,  244,
      244,  244,  244,  244,  244,  244,  244,  244,  244,  244,
      244,  244,  244,  244,  247,  243,  244,  248,  245,  244,
      249,  246,  244,  244,  244,  244,  244,  244,  244,  244,
      244,  244,  244,  244,  244,  244,  244,  244,  244,  244,
      244,  244,  244,  244,  244,  244,  244,  244,  244,  244,
      244,  244,  244,  244,  244,  244,  244,  244,  244,  244,
      244,  244,  244,  244,  244,  244,  244,  244,  244,  244,
      244,  250,  247,  244,  243,  243,  244,  244,  244,   49,

      244,  244,  244,  244,  244,  244,  244,  244,  244,  244,
      244,  244,  244,  244,  244,  244,  244,  244,  244,  244,
      244,  244,  244,  244,  244,  244,  244,  244,  244,  244,
      244,  244,  244,  244,  244,  244,  244,  244,  244,  244,
      244,  244,  244,  243,  244,  244,  244,  244,  244,  244,
      244,  244,  244,  244,  244,  244,  244,  244,  244,  244,
      244,  244,  244,  244,  244,  244,  244,  244,  244,  244,
      244,  244,  244,  244,  244,  244,  244,  244,  244,  244,
      244,  244,  244,  244,  244,  244,  244,  244,  244,  244,
      244,  244,  244,  244,  244,  244,  244,  244,  244,  244,

      244,  244,  244,  244,  244,  244,  244,  244,  244,  244,
      244,  244,  244,  244,  244,  244,  244,  244,  244,  244,
      244,  244,  244,  244,  244,  244,  244,  244,  244,  244,
      244,  244,  244,  244,  244,  244,  244,  244,  244,  244,
      244,  244,    0,  243,  243,  243,  243,  243,  243,  243
    } ;

static yyconst flex_int16_t yy_nxt[652] =
    {   0,
        4,    5,    6,    7,    8,    9,   10,   11,   12,   13,
       13,   13,   14,   15,   16,   17,   18,   19,   20,   21,
       22,    7,    7,   23,   24,   25,   26,   27,   28,   29,
       30,   31,    7,   32,   33,    7,   34,   14,   15,   16,
       17,   18,   19,   20,   21,   22,    7,    7,   23,   24,
       25,   26,   27,   28,   29,   30,   31,    7,   32,   33,
        7,   34,   35,    7,   38,   38,   41,   41,   40,   37,
      205,   43,   44,   45,   45,   45,   45,   46,   46,   46,
       46,   47,   45,   45,   45,   45,   50,  144,   58,   96,
       48,   47,   45,   45,   45,   45,   95,   59,   51,   54,

       48,   63,   52,   81,   55,   36,   56,   60,   36,   49,
       61,   50,   57,   58,   64,   48,   53,   65,   62,  243,
       67,   66,   59,   51,   54,   48,   63,   52,   81,   55,
       68,   56,   60,   73,   49,   61,   69,   57,   75,   64,
       70,   53,   65,   62,   71,   67,   66,   74,   77,   86,
       72,   79,   76,   84,   80,   68,   78,   82,   73,   83,
       85,   69,   90,   75,   88,   70,   87,   91,   89,   71,
       92,   92,   74,   77,   86,   72,   79,   76,   84,   80,
      243,   78,   82,  243,   83,   85,  243,   90,  243,   88,
      243,   87,   91,   89,   38,   38,   41,   41,   40,  101,

      102,   43,   46,   46,   46,   46,   47,   45,   45,   45,
       45,   46,   46,   46,   46,   48,  103,  104,  105,   97,
       46,   46,   46,   46,  101,  102,  108,   98,   48,   99,
       99,   99,   99,   94,   99,   99,   99,   99,  243,  109,
       48,  103,  104,  105,   97,  106,  111,  107,  112,  110,
      113,  108,  114,   48,  100,  100,  100,  100,  100,  100,
      100,  100,  100,  100,  109,  115,  116,  117,  118,  119,
      106,  111,  107,  112,  110,  113,  120,  114,  121,  122,
      123,  126,  124,  100,  100,  100,  100,  100,  100,  127,
      115,  116,  117,  118,  119,  125,  128,  129,  130,  131,

      132,  120,  133,  121,  122,  123,  126,  124,  134,  135,
      136,  137,  138,  140,  127,  143,  141,  243,  139,  243,
      125,  128,  129,  130,  131,  132,  142,  133,   92,   92,
      243,  147,  148,  134,  135,  136,  137,  138,  140,  149,
      143,  141,  145,  139,  146,  146,  146,  146,  150,  151,
      152,  142,   99,   99,   99,   99,  147,  148,  153,  154,
      155,  156,  157,  158,  149,  159,  243,  160,  161,  162,
      163,  164,  165,  150,  151,  152,  166,  167,  168,  169,
      170,  171,  172,  153,  154,  155,  156,  157,  158,  173,
      159,   94,  160,  161,  162,  163,  164,  165,  175,  174,

      176,  166,  167,  168,  169,  170,  171,  172,  177,  178,
      179,  180,  181,  183,  173,  184,  182,  146,  146,  146,
      146,  185,  186,  175,  174,  176,  146,  146,  146,  146,
      187,  188,  189,  177,  178,  179,  180,  190,  183,  191,
      184,  182,  192,  193,  194,  195,  185,  186,  196,  197,
      198,  199,  200,  201,  202,  187,  188,  189,  203,  204,
      206,  207,  190,  208,  191,  212,  243,  192,  193,  194,
      195,  213,  243,  196,  197,  198,  199,  200,  201,  202,
      209,  214,  215,  203,  204,  206,  207,  216,  208,  217,
      212,  210,  218,  219,  220,  221,  213,  211,  222,  223,

      224,  225,  226,  227,  228,  209,  214,  215,  229,  230,
      231,  232,  216,  233,  217,  234,  210,  218,  219,  220,
      221,  235,  211,  222,  223,  224,  225,  226,  227,  228,
      236,  237,  238,  229,  230,  231,  232,  239,  233,  240,
      234,  241,  242,  243,  243,  243,  235,  243,  243,  243,
      243,  243,  243,  243,  243,  236,  237,  238,  243,  243,
      243,  243,  239,  243,  240,  243,  241,  242,   39,  243,
       39,   42,  243,   42,   93,  243,   93,   38,  243,   38,
       41,  243,   41,   92,  243,   92,    3,  243,  243,  243,
      243,  243,  243,  243,  243,  243,  243,  243,  243,  243,

      243,  243,  243,  243,  243,  243,  243,  243,  243,  243,
      243,  243,  243,  243,  243,  243,  243,  243,  243,  243,
      243,  243,  243,  243,  243,  243,  243,  243,  243,  243,
      243,  243,  243,  243,  243,  243,  243,  243,  243,  243,
      243,  243,  243,  243,  243,  243,  243,  243,  243,  243,
      243
    } ;

static yyconst flex_int16_t yy_chk[652] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    8,    8,    9,    9,    8,  244,
      181,    9,   10,   10,   10,   10,   10,   11,   11,   11,
       11,   12,   12,   12,   12,   12,   14,   92,   17,   41,
       12,   13,   13,   13,   13,   13,   38,   18,   15,   16,

       13,   20,   15,   28,   16,   36,   16,   18,    5,   12,
       19,   14,   16,   17,   20,   12,   15,   21,   19,    3,
       22,   21,   18,   15,   16,   13,   20,   15,   28,   16,
       22,   16,   18,   24,   12,   19,   22,   16,   25,   20,
       23,   15,   21,   19,   23,   22,   21,   24,   26,   31,
       23,   27,   25,   30,   27,   22,   26,   29,   24,   29,
       30,   22,   33,   25,   32,   23,   31,   34,   32,   23,
       35,   35,   24,   26,   31,   23,   27,   25,   30,   27,
        0,   26,   29,    0,   29,   30,    0,   33,    0,   32,
        0,   31,   34,   32,   39,   39,   42,   42,   39,   50,

       51,   42,   44,   44,   44,   44,   45,   45,   45,   45,
       45,   46,   46,   46,   46,   45,   52,   54,   55,   46,
       47,   47,   47,   47,   50,   51,   57,   48,   47,   48,
       48,   48,   48,   35,   98,   98,   98,   98,    0,   58,
       45,   52,   54,   55,   46,   56,   59,   56,   60,   58,
       61,   57,   62,   47,   49,   49,   49,   49,   49,   49,
       49,   49,   49,   49,   58,   63,   64,   65,   66,   68,
       56,   59,   56,   60,   58,   61,   69,   62,   70,   71,
       72,   74,   73,   49,   49,   49,   49,   49,   49,   75,
       63,   64,   65,   66,   68,   73,   77,   79,   80,   81,

       82,   69,   83,   70,   71,   72,   74,   73,   84,   85,
       86,   87,   88,   89,   75,   91,   90,    0,   88,    0,
       73,   77,   79,   80,   81,   82,   90,   83,   93,   93,
        0,  101,  102,   84,   85,   86,   87,   88,   89,  103,
       91,   90,   97,   88,   97,   97,   97,   97,  104,  105,
      106,   90,   99,   99,   99,   99,  101,  102,  107,  108,
      109,  110,  111,  113,  103,  114,    0,  116,  117,  118,
      119,  121,  122,  104,  105,  106,  123,  124,  126,  127,
      129,  130,  131,  107,  108,  109,  110,  111,  113,  132,
      114,   93,  116,  117,  118,  119,  121,  122,  134,  132,

      135,  123,  124,  126,  127,  129,  130,  131,  137,  138,
      140,  141,  142,  147,  132,  148,  142,  145,  145,  145,
      145,  150,  152,  134,  132,  135,  146,  146,  146,  146,
      153,  154,  155,  137,  138,  140,  141,  156,  147,  158,
      148,  142,  161,  163,  164,  167,  150,  152,  168,  170,
      171,  172,  173,  174,  178,  153,  154,  155,  179,  180,
      182,  183,  156,  185,  158,  187,    0,  161,  163,  164,
      167,  188,    0,  168,  170,  171,  172,  173,  174,  178,
      186,  190,  192,  179,  180,  182,  183,  193,  185,  195,
      187,  186,  196,  197,  201,  203,  188,  186,  206,  208,

      209,  210,  211,  212,  219,  186,  190,  192,  220,  221,
      224,  225,  193,  226,  195,  227,  186,  196,  197,  201,
      203,  228,  186,  206,  208,  209,  210,  211,  212,  219,
      229,  233,  235,  220,  221,  224,  225,  236,  226,  237,
      227,  238,  239,    0,    0,    0,  228,    0,    0,    0,
        0,    0,    0,    0,    0,  229,  233,  235,    0,    0,
        0,    0,  236,    0,  237,    0,  238,  239,  245,    0,
      245,  246,    0,  246,  247,    0,  247,  248,    0,  248,
      249,    0,  249,  250,    0,  250,  243,  243,  243,  243,
      243,  243,  243,  243,  243,  243,  243,  243,  243,  243,

      243,  243,  243,  243,  243,  243,  243,  243,  243,  243,
      243,  243,  243,  243,  243,  243,  243,  243,  243,  243,
      243,  243,  243,  243,  243,  243,  243,  243,  243,  243,
      243,  243,  243,  243,  243,  243,  243,  243,  243,  243,
      243,  243,  243,  243,  243,  243,  243,  243,  243,  243,
      243
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "colorbar/lex.L"
/* Copyright (C) 1999-2015
 * Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 * For conditions of distribution and use, see copyright notice in "copyright"
 */
#line 12 "colorbar/lex.L"
  #include <stdio.h>
  #include <stdlib.h>
  #include <string.h>

  #include "parser.H"

  extern YYSTYPE* cblval;
/* rules */
#line 646 "colorbar/lex.C"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
#define ECHO LexerOutput( yytext, yyleng )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
\
	if ( (result = LexerInput( (char *) buf, max_size )) < 0 ) \
		YY_FATAL_ERROR( "input in flex scanner failed" );

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) LexerError( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1
#define YY_DECL int yyFlexLexer::yylex()
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 26 "colorbar/lex.L"


#line 749 "colorbar/lex.C"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = & std::cin;

		if ( ! yyout )
			yyout = & std::cout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 244 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 243 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 28 "colorbar/lex.L"
{return ADJUST_;}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 29 "colorbar/lex.L"
{return BEGIN_;}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 30 "colorbar/lex.L"
{return BIAS_;}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 31 "colorbar/lex.L"
{return BW_;}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 32 "colorbar/lex.L"
{return CHANNEL_;}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 33 "colorbar/lex.L"
{return CMYK_;}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 34 "colorbar/lex.L"
{return COLORMAP_;}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 35 "colorbar/lex.L"
{return COLORBAR_;}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 36 "colorbar/lex.L"
{return COLORSPACE_;}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 37 "colorbar/lex.L"
{return CONTRAST_;}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 38 "colorbar/lex.L"
{return CURSOR_;}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 39 "colorbar/lex.L"
{return DEBUG_;}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 40 "colorbar/lex.L"
{return DELETE_;}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 41 "colorbar/lex.L"
{return EDIT_;}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 42 "colorbar/lex.L"
{return END_;}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 43 "colorbar/lex.L"
{return GET_;}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 44 "colorbar/lex.L"
{return GRAY_;}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 45 "colorbar/lex.L"
{return FALSE_;}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 46 "colorbar/lex.L"
{return FILE_;}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 47 "colorbar/lex.L"
{return HEIGHT_;}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 48 "colorbar/lex.L"
{return HIDE_;}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 49 "colorbar/lex.L"
{return ID_;}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 50 "colorbar/lex.L"
{return INVERT_;}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 51 "colorbar/lex.L"
{return ITT_;}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 52 "colorbar/lex.L"
{return LEVEL_;}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 53 "colorbar/lex.L"
{return LIST_;}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 54 "colorbar/lex.L"
{return LOAD_;}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 55 "colorbar/lex.L"
{return MACOSX_;}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 56 "colorbar/lex.L"
{return MAP_;}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 57 "colorbar/lex.L"
{return MOTION_;}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 58 "colorbar/lex.L"
{return N_;}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 59 "colorbar/lex.L"
{return NAME_;}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 60 "colorbar/lex.L"
{return NO_;}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 61 "colorbar/lex.L"
{return OFF_;}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 62 "colorbar/lex.L"
{return ON_;}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 63 "colorbar/lex.L"
{return POSTSCRIPT_;}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 64 "colorbar/lex.L"
{return PRINT_;}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 65 "colorbar/lex.L"
{return QUERY_;}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 66 "colorbar/lex.L"
{return RESET_;}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 67 "colorbar/lex.L"
{return RESOLUTION_;}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 68 "colorbar/lex.L"
{return RGB_;}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 69 "colorbar/lex.L"
{return SAVE_;}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 70 "colorbar/lex.L"
{return SHOW_;}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 71 "colorbar/lex.L"
{return TAG_;}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 72 "colorbar/lex.L"
{return TRUE_;}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 73 "colorbar/lex.L"
{return VALUE_;}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 74 "colorbar/lex.L"
{return VAR_;}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 75 "colorbar/lex.L"
{return VERSION_;}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 76 "colorbar/lex.L"
{return WIDTH_;}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 77 "colorbar/lex.L"
{return WIN32_;}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 78 "colorbar/lex.L"
{return WINDOW_;}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 79 "colorbar/lex.L"
{return Y_;}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 80 "colorbar/lex.L"
{return YES_;}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 82 "colorbar/lex.L"
{ // Integer
		  cblval->integer = atoi(yytext);
		  return INT;
		}
	YY_BREAK
case 55:
#line 88 "colorbar/lex.L"
case 56:
YY_RULE_SETUP
#line 88 "colorbar/lex.L"
{ // Real Number
		  cblval->real = atof(yytext);
		  return REAL;
		}
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 93 "colorbar/lex.L"
{ // Pointer
		  cblval->ptr = (void*)strtoul(yytext,NULL,16);
		  return POINTER;
		}
	YY_BREAK
case 58:
#line 99 "colorbar/lex.L"
case 59:
YY_RULE_SETUP
#line 99 "colorbar/lex.L"
{ // Quoted String
		  int ll = (yyleng-2)<(CBBUFSIZE-1) ? (yyleng-2):(CBBUFSIZE-1);
		  strncpy(cblval->str,yytext+1,ll); // skip the " " 
	          cblval->str[ll] = '\0'; // Remove the '"' 
		  return STRING;
		}
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 106 "colorbar/lex.L"
{ // Quoted String
		  int ll = (yyleng-2)<(CBBUFSIZE-1) ? (yyleng-2):(CBBUFSIZE-1);
		  strncpy(cblval->str,yytext+1,ll); // skip the '{'
	          cblval->str[ll] = '\0'; // Remove the '}'
		  return STRING;
		}
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 113 "colorbar/lex.L"
{ // General String-- at least 2 printable chars
		  int ll = yyleng <(CBBUFSIZE-1) ? yyleng:(CBBUFSIZE-1);
		  strncpy(cblval->str,yytext,ll);
	          cblval->str[ll] = '\0';
		  return STRING;
		}
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 120 "colorbar/lex.L"
{ // White Spaces
		} 
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 123 "colorbar/lex.L"
{ // Else, return the char
		  return yytext[0];
		}
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 127 "colorbar/lex.L"
ECHO;
	YY_BREAK
#line 1169 "colorbar/lex.C"
case YY_STATE_EOF(INITIAL):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* The contents of this function are C++ specific, so the () macro is not used.
 */
yyFlexLexer::yyFlexLexer( std::istream* arg_yyin, std::ostream* arg_yyout )
{
	yyin = arg_yyin;
	yyout = arg_yyout;
	yy_c_buf_p = 0;
	yy_init = 0;
	yy_start = 0;
	yy_flex_debug = 0;
	yylineno = 1;	// this will only get updated if %option yylineno

	yy_did_buffer_switch_on_eof = 0;

	yy_looking_for_trail_begin = 0;
	yy_more_flag = 0;
	yy_more_len = 0;
	yy_more_offset = yy_prev_more_offset = 0;

	yy_start_stack_ptr = yy_start_stack_depth = 0;
	yy_start_stack = NULL;

	yy_buffer_stack = 0;
	yy_buffer_stack_top = 0;
	yy_buffer_stack_max = 0;

	yy_state_buf = 0;

}

/* The contents of this function are C++ specific, so the () macro is not used.
 */
yyFlexLexer::~yyFlexLexer()
{
	delete [] yy_state_buf;
	cbfree(yy_start_stack  );
	yy_delete_buffer( YY_CURRENT_BUFFER );
	cbfree(yy_buffer_stack  );
}

/* The contents of this function are C++ specific, so the () macro is not used.
 */
void yyFlexLexer::switch_streams( std::istream* new_in, std::ostream* new_out )
{
	if ( new_in )
		{
		yy_delete_buffer( YY_CURRENT_BUFFER );
		yy_switch_to_buffer( yy_create_buffer( new_in, YY_BUF_SIZE  ) );
		}

	if ( new_out )
		yyout = new_out;
}

#ifdef YY_INTERACTIVE
size_t yyFlexLexer::LexerInput( char* buf, size_t /* max_size */ )
#else
size_t yyFlexLexer::LexerInput( char* buf, size_t max_size )
#endif
{
	if ( yyin->eof() || yyin->fail() )
		return 0;

#ifdef YY_INTERACTIVE
	yyin->get( buf[0] );

	if ( yyin->eof() )
		return 0;

	if ( yyin->bad() )
		return -1;

	return 1;

#else
	(void) yyin->read( buf, max_size );

	if ( yyin->bad() )
		return -1;
	else
		return yyin->gcount();
#endif
}

void yyFlexLexer::LexerOutput( const char* buf, size_t size )
{
	(void) yyout->write( buf, size );
}

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
int yyFlexLexer::yy_get_next_buffer()
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					cbrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) cbrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    yy_state_type yyFlexLexer::yy_get_previous_state()
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 244 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    yy_state_type yyFlexLexer::yy_try_NUL_trans( yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 244 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 243);

	return yy_is_jam ? 0 : yy_current_state;
}

    void yyFlexLexer::yyunput( int c, register char* yy_bp)
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register yy_size_t number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

    int yyFlexLexer::yyinput()
{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyFlexLexer::yyrestart( std::istream* input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yyFlexLexer::yy_switch_to_buffer( YY_BUFFER_STATE new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

    void yyFlexLexer::yy_load_buffer_state()
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yyFlexLexer::yy_create_buffer( std::istream* file, int size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) cballoc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) cballoc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yyFlexLexer::yy_delete_buffer( YY_BUFFER_STATE b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		cbfree((void *) b->yy_ch_buf  );

	cbfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    void yyFlexLexer::yy_init_buffer( YY_BUFFER_STATE b, std::istream* file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

	b->yy_is_interactive = 0;
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yyFlexLexer::yy_flush_buffer( YY_BUFFER_STATE b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yyFlexLexer::yypush_buffer_state (YY_BUFFER_STATE new_buffer)
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yyFlexLexer::yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
void yyFlexLexer::yyensure_buffer_stack(void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)cballoc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)cbrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

    void yyFlexLexer::yy_push_state( int new_state )
{
    	if ( (yy_start_stack_ptr) >= (yy_start_stack_depth) )
		{
		yy_size_t new_size;

		(yy_start_stack_depth) += YY_START_STACK_INCR;
		new_size = (yy_start_stack_depth) * sizeof( int );

		if ( ! (yy_start_stack) )
			(yy_start_stack) = (int *) cballoc(new_size  );

		else
			(yy_start_stack) = (int *) cbrealloc((void *) (yy_start_stack),new_size  );

		if ( ! (yy_start_stack) )
			YY_FATAL_ERROR( "out of memory expanding start-condition stack" );
		}

	(yy_start_stack)[(yy_start_stack_ptr)++] = YY_START;

	BEGIN(new_state);
}

    void yyFlexLexer::yy_pop_state()
{
    	if ( --(yy_start_stack_ptr) < 0 )
		YY_FATAL_ERROR( "start-condition stack underflow" );

	BEGIN((yy_start_stack)[(yy_start_stack_ptr)]);
}

    int yyFlexLexer::yy_top_state()
{
    	return (yy_start_stack)[(yy_start_stack_ptr) - 1];
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

void yyFlexLexer::LexerError( yyconst char msg[] )
{
    	std::cerr << msg << std::endl;
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *cballoc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *cbrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void cbfree (void * ptr )
{
	free( (char *) ptr );	/* see cbrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 127 "colorbar/lex.L"



